@@ -1,5 +1,5 @@
 package Email::MIME::RFC2047::MailboxList;
-our $VERSION = '0.89_02';
+our $VERSION = '0.90';
 
 use strict;
 use base qw(Email::MIME::RFC2047::AddressList);
@@ -36,8 +36,8 @@ Email::MIME::RFC2047::MailboxList - Handling of MIME encoded mailbox lists
 =head1 DESCRIPTION
 
 This module handles RFC 2822 'mailbox-lists'. It is a subclass of
-Email::MIME::RFC2047::AddressList and works the same but only allows
-mailboxes as items.
+L<Email::MIME::RFC2047::AddressList> and works the same but only allows
+L<Email::MIME::RFC2047::Mailbox> items.
 
 =head1 AUTHOR
 
